boss.container - heros-boss 0.6.10 documentation

Skip to content
Back to top
View this page

# boss.container

Includes utilities to handle BOSS starting in a container.

## Functions

`is_in_container`() | Checks if the current process is running inside a docker or podman container.
`prepare_container`() | Installs extra packages to the docker container.

## Module Contents

boss.container.is_in_container()

  Checks if the current process is running inside a docker or podman container.

boss.container.prepare_container()

  Installs extra packages to the docker container.